@@ -5,10 +5,6 @@ import os
 parent_dir = os.path.dirname(os.path.abspath(__file__))
 build_dir = os.path.join(parent_dir, "frontend/build")
 component_func = components.declare_component("highlightable_text", path=build_dir)
-_component_func = components.declare_component(
-    "highlightable_text",
-    path="component/frontend/build",  # Fetch frontend component from local webserver
-)
 
 # Define a public function for the package,
 # which wraps the caller to the frontend code
